@@ -52,12 +52,13 @@ class GSPeerConnectionBroadcasterPi:
         return relay.subscribe(microfon.audio)
 
     @classmethod
-    async def create(cls, gsdbs):
+    async def create(cls, gsdbs, picam):
         self = GSPeerConnectionBroadcasterPi()
         self.rtconfiList = []
 
         with picamera.PiCamera() as camera:
             self.gsdbs = gsdbs
+            picam = camera
             if self.gsdbs.credentials["stunenable"]:
                 self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
             if self.gsdbs.credentials["turnenable"]:
@@ -130,9 +131,9 @@ class GSPeerConnectionBroadcasterPi:
                 transceiver.setCodecPreferences(preferences)
 
                 if self.gsdbs.credentials["audio"]:
+                    pc.addTransceiver("audio", direction="sendonly")
                     audio = self.getMicrofonRelay()
                     pc.addTrack(audio)
-                    # transceiver1 = pc.addTransceiver("audio", direction="sendonly")
 
                 for t in pc.getTransceivers():
                     if t.kind == "video":
